@@ -8,7 +8,7 @@ import re
 import sys
 import logging
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
 """
     This is a library of decorators designed for writing scripts quickly. This
@@ -367,7 +367,37 @@ def entrypoint(func):
         decorators further out will not be applied to the function until after
         it is run.
     """ 
-    return autorun(acceptargv(func), 2)
+    frame_local = sys._getframe(1).f_locals
+    if '__name__' in frame_local and frame_local['__name__'] == '__main__':
+        argv = sys.argv[1:]
+
+        parser = signature_parser(func)
+        try:
+            kwargs = parser.parse_args(argv).__dict__
+            
+            # special cli flags
+            
+            # --version is handled by ArgParse
+            #if kwargs.get('version'):
+            #    print module_version(func)
+            #    return
+            if 'version' in kwargs.keys():
+                del kwargs['version']
+            
+            # --debug
+            if kwargs.get('debug'):
+                logging.basicConfig(level=logging.DEBUG)
+            del kwargs['debug']
+                            
+            if "__args" in kwargs:
+                return func(*_correct_args(func, kwargs))
+            else:
+                return func(**kwargs)
+            
+        except UsageError, e:
+            parser.error(e.message)
+            
+    return func
 
 def entrywithfile(*argspec, **kwspec):
     """
